---
title: 'mod\_bosh'
---

BOSH allows clients to use HTTP to communicate with XMPP servers. Often
used to allow browser based webclients to connect to an XMPP server,
BOSH is also useful in situations where a user is behind a firewall or
NAT is preventing connections to the required server ports.

# Details

mod\_bosh implements
[XEP-0124](http://xmpp.org/extensions/xep-0124.html) and
[XEP-0206](http://xmpp.org/extensions/xep-0206.html). For more advanced
configuration options see [Setting up a BOSH
server](/doc/setting_up_bosh).

# Usage

``` {.code .lua}
modules_enabled = {
    -- Other modules
    "bosh"; -- Enable mod_bosh
}
```

# Configuration

Note that these options only work in the **global section** of the
config.

  ------------------------------------------------------------------------------------------------
  Option                   Default      Notes
  ------------------------ ------------ ----------------------------------------------------------
  bosh\_max\_inactivity    60           Maximum amount of time in seconds a client may remain
                                        silent for, with no requests

  consider\_bosh\_secure   false        If true then BOSH connections will be allowed when
                                        requiring encryption, even if unencrypted

  cross\_domain\_bosh      false        Set to true to enable cross-domain requests from websites,
                                        or a list like
                                        `{ "http://jabber.org", "http://prosody.im" }`{.lua}
  ------------------------------------------------------------------------------------------------

## Advanced options

::: {.alert .alert-warning}
:warning: These advanced options are best left at their defaults unless
you know what you are doing
:::

  ------------------------------------------------------------------------
  Option                  Default                  Notes
  ----------------------- ------------------------ -----------------------
  bosh\_default\_hold     1                        Maximum number of
                                                   requests the server
                                                   will hold open for a
                                                   client

  bosh\_max\_requests     2                        Maximum number of
                                                   requests a client may
                                                   make to the server at a
                                                   time

  bosh_max_wait           120                      The maximum amount of time
                                                   a single request will be
                                                   held open by Prosody with
                                                   no response.
                                                   Clients may request a lower value
                                                   for a given session.

  trusted\_proxies        `{ "127.0.0.1", "::1" }` A list of proxies to
                                                   trust, used to find a
                                                   client\'s real IP
  ------------------------------------------------------------------------

# Example

``` {.code .lua}
modules_enabled = {
    -- Other modules
    "bosh"; -- Enable mod_bosh
}
 
 
bosh_max_inactivity = 60
consider_bosh_secure = true -- Use if proxying HTTPS->HTTP on the server side
cross_domain_bosh = true -- Allow access from scripts on any site with no proxy (requires a modern browser)
```
