---
title: 'mod\_pep'
---

::: {.alert .alert-info}
This page documents the new version of mod\_pep introduced in 0.11.0.
Previous version, present until 0.10, was renamed
[mod\_pep\_simple](/doc/modules/mod_pep_simple).
:::

Often users will want to publish details about their mood, the music
they are listening to or the activity they are currently taking part in.
Enabling mod\_pep will allow users to publish that information and have
interested parties receive it.

Example uses:

-   [XEP-0084: Avatar](https://xmpp.org/extensions/xep-0084.html)
-   [XEP-0107: Mood](https://xmpp.org/extensions/xep-0107.html)
-   [XEP-0108: Activity](https://xmpp.org/extensions/xep-0108.html)
-   [XEP-0277: Microblogging](https://xmpp.org/extensions/xep-0277.html)
-   [XEP-0384: OMEMO](https://xmpp.org/extensions/xep-0384.html)
-   [XEP-0048: Bookmarks](https://xmpp.org/extensions/xep-0048.html)

# Details

mod\_pep implements
[XEP-0163](https://xmpp.org/extensions/xep-0163.html). Since Prosody
0.11.0 it is based on the same PubSub library that powers
[mod\_pubsub](/doc/modules/mod_pubsub), which provide many more features
than the minimal subset mandated by XEP-0163.

The previous version is available as
[mod\_pep\_simple](/doc/modules/mod_pep_simple) for those that wish to
have more performance in exchange for fewer advanced PubSub features .

Since the PubSub library supports access controls, mod\_pep also allow
users to decide who will have access to the various nodes. E.g. OMEMO
key bundles are commonly made completely public while bookmarks are
accessible only by the user themselves.

# Usage

``` {.code .lua}
    modules_enabled = {
        -- Other modules
        "pep"; -- Enable mod_pep
    }
```

# Configuration

The `pep_max_items` option sets a maximum value for how many items each
node can be configured to keep. It defaults to 256.

``` {.lua}
pep_max_items = 256
```

Two options were added in 0.11.11 to limit resource usage:

`pep_service_cache_size`
:   How many user pubsub services will be kept in memory. Optimal value
    will likely somewhere between the number of online users and the
    total number of users. Defaults to 1000.

`pep_info_cache_size`
:   Size of cache of data for keeping track of what events entities are
    interested in. Defaults to 10000.

# Example

``` {.code .lua}
    modules_enabled = {
        -- Other modules
        "pep"; -- Enable mod_pep
    }
```
