---
abstract: Handles limits on user account creation
title: mod_register_limits
---

This module enforces limits on account creation, such as rate limits and
restrictions to certain sets of IP addresses.

# Details

This functionality was previously part of mod_register where it only
applied to in-band registration, but now it applies to registration via
methods provided by 3rd-party modules such as web forms.

# Configuration

  Option                                        Default   Notes
  --------------------------------------------- --------- -------------------------------------------------------------------------------------------------------------------------------------------------
  registration_blacklist                        { }       List of IP addresses to deny registration
  registration_whitelist                        { }       List of IP addresses to allow registration (bypassing all throttling and limits)
  whitelist_registration_only                   false     Whether to only allow IPs in registration_whitelist to register
  min_seconds_between_registrations             nil       The number of seconds a client at a particular IP address must wait before it can register another account
  registration_throttle_max                     nil       Defaults to 1 if min_seconds_between_registrations is set, otherwise unset.
  registration_throttle_period                  nil       Defaults to the same value as min_seconds_between_registrations.
  registration_throttle_cache_size              100       How many IP addresses to keep track of for throttling.
  blacklist_on_registration_throttle_overload   false     Determines behavior if the above cache overflows. If true and the IP is still over the limit, add it to the registration blacklist.

# Example

``` {.lua}
modules_enabled = {
    "register";
    "register_limits";
}
registration_whitelist = { "127.0.0.1", "::1" }
registration_blacklist = { "192.0.2.0" }
min_seconds_between_registrations = 60
```
