---
title: Downloading and Installing Prosody
---

Latest version:
:   [\_LATESTRELEASE](/doc/release/_LATESTRELEASE)

Installing Prosody is quite straightforward in most cases. Prosody is
available for many of the major operating systems.

If we have no package for yours, you should be able to install using the
source package, see [Source](#source_code) below.

::: {.alert .alert-info}
[:bulb:]{.icon} **Tip:** New to XMPP? Looking for a simple preconfigured
complete messaging server you can run in Docker? Take a look at our sister
project, [Snikket](https://snikket.org/){.alert-link}!
:::

# Linux

## Debian and Ubuntu {#debian_and_ubuntu}

Binary packages are available for all current Debian and Ubuntu
releases.

To install the version of Prosody available in your distribution's
official repositories, simply run:

``` {.code .bash}
sudo apt install prosody
```

To keep up to date with the latest (and greatest!) Prosody releases, we
recommend that you also [add our
repository](/download/package_repository), as distributions may lag
behind the latest version a bit. The repository also has [nightly
builds](#nightly_builds) of active branches.

## Fedora

RPM packages for Prosody for all active Fedora releases are available to
install via `dnf`, simply run as `root`:

``` {.code .bash}
dnf install prosody
```

## Red Hat Enterprise Linux, CentOS and Rocky {#red_hat_enterprise_linux}

Red Hat Enterprise Linux (RHEL) itself and thus derivatives like CentOS
or Rocky Linux don't ship Prosody, but the Fedora-driven repository [Extra
Packages for Enterprise Linux (EPEL)](https://fedoraproject.org/wiki/EPEL)
is doing so, if it's
[enabled](https://fedoraproject.org/wiki/EPEL/FAQ#howtouse).

In RHEL 8 the `codeready-builder-for-rhel-8-$(arch)-rpms` repository
should be enabled, and in CentOS and Rocky Linux 8 the `powertools`
repository should be enabled.

[Prosody is available to
install](https://bodhi.fedoraproject.org/updates/?like=prosody) from all
active EPEL releases via `yum`, simply run as `root`:

``` {.code .bash}
yum install prosody
```

## Gentoo

Prosody is available in the Portage tree as
[net-im/prosody](https://packages.gentoo.org/package/net-im/prosody),
simply run as `root`:

``` {.code .bash}
emerge --ask net-im/prosody
```

## Arch Linux {#arch_linux}

Arch Linux packages for Prosody are available [in their
repositories](http://www.archlinux.org/packages/?q=prosody).

Detailed information on installing Prosody on Arch can be found on the
[ArchWiki](http://wiki.archlinux.org/index.php/Prosody).

## OpenSUSE

OpenSUSE packages for Prosody are [available from
here](http://software.opensuse.org/package/prosody).

# Mac OS X {#mac_os_x}

OS X users can use [Homebrew](http://brew.sh/) to install the latest
version of Prosody. After [installing Homebrew](http://brew.sh/#install)
simply run:

``` {.code .bash}
brew tap prosody/prosody 
brew install prosody
```

# BSD

Prosody is available for the various BSD flavours:

-   FreeBSD: [net-im/prosody](https://www.freshports.org/net-im/prosody/)
-   NetBSD: [chat/prosody](https://pkgsrc.se/chat/prosody)
-   OpenBSD: [net/prosody](https://openports.se/net/prosody)

# Source code {#source_code}

Prosody source archives for each release are available
[here](https://prosody.im/downloads/source/).

Alternatively you can obtain the latest source code from our [Mercurial
repository](/source/start). Here are notes on how to [install from
source code](/doc/installing_from_source).

*Please note that while the latest source may contain new and exciting
features, it is not always stable and production ready. If you find any
anomalies please submit your bug reports or bug fixes after reading the
instructions [here](/bugs/start).\
Thank you.*

# Nightly builds {#nightly_builds}

Nightly builds are available for all active branches.  Currently the
builds only have packages for Debian and Ubuntu.

To install a nightly build, first [add our
repository](/download/package_repository), then install the package for
the branch, named like `prosody-BRANCH`. To e.g. install the latest
trunk build:

```bash
sudo apt install prosody-trunk
```

# Windows

::: {.alert .alert-warning}
[:warning:]{.icon} Windows support has been deprecated. Downloads are no
longer available.
:::

Alternatives include [Windows Subsystem for Linux][wsl] and [Docker][].

[wsl]: https://docs.microsoft.com/en-us/windows/wsl/install-win10
[Docker]: https://github.com/prosody/prosody-docker

## FAQ

Please contact <developers@prosody.im> with any questions not answered
here.

> Why windows support is unavailable now?

-   We don't have the resources (in the form of developer time) to
    maintain a Windows version.
-   The last version before support was dropped has unresolved security
    issues.

# Next steps {#next_steps}

Hopefully you now have a server up and running. The next step is to
[configure](/doc/configure) it, the only thing you are required to do is
to tell the server what hosts you want Prosody to serve, see [Adding a
Host](/doc/configure#adding_a_host) for more info.

Finally you will want to create yourself and any other users accounts.
For the various ways of doing so, see our [Creating
Accounts](/doc/creating_accounts) article.

[Let us know](/discuss) how you get on! [:smile:]{.icon}
